@@ -1,4 +1,4 @@
-# $Id: ExpatXS.pm,v 1.29 2005/03/07 10:32:23 cvspetr Exp $
+# $Id: ExpatXS.pm,v 1.31 2005/03/16 14:50:26 cvspetr Exp $
 
 package XML::SAX::ExpatXS;
 use strict;
@@ -10,18 +10,22 @@ use DynaLoader ();
 use Carp;
 use IO::File;
 
-$VERSION = '1.06';
+$VERSION = '1.07';
 @ISA = qw(DynaLoader XML::SAX::Base);
 
 XML::SAX::ExpatXS->bootstrap($VERSION);
 
-my @supported_features = (
-	'http://xml.org/sax/features/namespaces',
-	'http://xml.org/sax/features/external-general-entities',
-	'http://xmlns.perl.org/sax/join-character-data',
-	'http://xmlns.perl.org/sax/ns-attributes',
-	'http://xmlns.perl.org/sax/locator',
+my @features = (
+	['http://xml.org/sax/features/namespaces', 1],
+	['http://xml.org/sax/features/external-general-entities', 1],
+        ['http://xml.org/sax/features/xmlns-uris', 0],
+        ['http://xmlns.perl.org/sax/version-2.1', 1],
+	['http://xmlns.perl.org/sax/join-character-data', 1],
+	['http://xmlns.perl.org/sax/ns-attributes', 1],
+	['http://xmlns.perl.org/sax/locator', 1]
 			 );
+my @supported_features = map($_->[0], @features);
+
 
 #------------------------------------------------------------
 # API methods
@@ -31,11 +35,9 @@ sub new {
     my $proto = shift;
     my $options = ($#_ == 0) ? shift : { @_ };
 
-    $options->{Features}->{$supported_features[0]} = 1;
-    $options->{Features}->{$supported_features[1]} = 1;
-    $options->{Features}->{$supported_features[2]} = 1;
-    $options->{Features}->{$supported_features[3]} = 1;
-    $options->{Features}->{$supported_features[4]} = 1;
+    foreach (@features) {
+	$options->{Features}->{$_->[0]} = $_->[1];
+    }
 
     return $proto->SUPER::new($options);
 }
@@ -204,7 +206,7 @@ XML::SAX::ExpatXS - Perl SAX 2 XS extension to Expat parser
 
  $handler = MyHandler->new();
  $parser = XML::SAX::ExpatXS->new( Handler => $handler );
- $parser->parse($uri);
+ $parser->parse_uri($uri);
   #or
  $parser->parse_string($xml);
 
@@ -212,7 +214,8 @@ XML::SAX::ExpatXS - Perl SAX 2 XS extension to Expat parser
 
 XML::SAX::ExpatXS is a direct XS extension to Expat XML parser. It implements
 Perl SAX 2.1 interface. See http://perl-xml.sourceforge.net/perl-sax/ for
-Perl SAX description.
+Perl SAX API description. Any deviations from the Perl SAX 2.1 specification 
+are considered to be bugs.
 
 =head2 Features
 
@@ -220,19 +223,24 @@ The parser behavior can be changed by setting features.
 
  $parser->set_feature(FEATURE, VALUE);
 
-XML::SAX::ExpatXS provide these features:
+XML::SAX::ExpatXS provides these adjustable features:
 
 =over
 
-=item http://xmlns.perl.org/sax/join-character-data
+=item C<http://xmlns.perl.org/sax/join-character-data>
 
 Consequent character data are joined (1, default) or not (0).
 
-=item http://xmlns.perl.org/sax/ns-attributes
+=item C<http://xmlns.perl.org/sax/ns-attributes>
 
 Namespace attributes are reported as common attributes (1, default) or not (0).
 
-=item http://xmlns.perl.org/sax/locator
+=item C<http://xml.org/sax/features/xmlns-uris>
+
+When reported, xmlns and xmlns:* attributes are put into no namespace (0, default)
+or into C<http://www.w3.org/2000/xmlns/> namespace (1).
+
+=item C<http://xmlns.perl.org/sax/locator>
 
 Document locator is updated (1, default) for ContentHadler events or not (0).
 
@@ -240,7 +248,7 @@ Document locator is updated (1, default) for ContentHadler events or not (0).
 
 =head1 AUTHORS
 
-Matt Sergeant <matt AT sergeant DOT org>
-Petr Cimprich <petr AT gingerall DOT org> (maintainer)
+ Matt Sergeant <matt AT sergeant DOT org>
+ Petr Cimprich <petr AT gingerall DOT org> (maintainer)
 
 =cut
